@@ -47,7 +47,7 @@ class CalFilterPartStatusProxyModel;
 static bool isStructuralCollection(const Akonadi::Collection &collection)
 {
     QStringList mimeTypes;
-    mimeTypes << QLatin1String("text/calendar")
+    mimeTypes << QStringLiteral("text/calendar")
               << KCalCore::Event::eventMimeType()
               << KCalCore::Todo::todoMimeType()
               << KCalCore::Journal::journalMimeType();
@@ -70,7 +70,7 @@ public:
     {
     }
 
-    QVariant data(const QModelIndex &index, int role) const
+    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE
     {
         if (role == Qt::CheckStateRole) {
             // Don't show the checkbox if the collection can't contain incidences
@@ -135,7 +135,7 @@ public:
     Akonadi::EntityMimeTypeFilterModel *mFilteredETM;
 
     // akonadi id to collections
-    QHash<Akonadi::Entity::Id, Akonadi::Collection> mCollectionMap;
+    QHash<Akonadi::Collection::Id, Akonadi::Collection> mCollectionMap;
     CheckableProxyModel *mCheckableProxyModel;
     Akonadi::CollectionFilterProxyModel *mCollectionProxyModel;
     Akonadi::CalFilterProxyModel *mCalFilterProxyModel; //KCalCore::CalFilter stuff
